import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import React from 'react';
import { Select } from '@redux-devtools/ui';
import { StyleUtilsContext } from '../styles/createStylingFromTheme';
import debounce from 'lodash.debounce';
import { sortQueryOptions } from '../utils/comparators';
import { filterQueryOptions } from '../utils/filters';
import { SortOrderButton } from './SortOrderButton';
import { RegexIcon } from './RegexIcon';
const selectId = 'rtk-query-comp-select';
const searchId = 'rtk-query-search-query';
const filterSelectId = 'rtk-query-search-query-select';
const searchPlaceholder = 'filter query by...';
const labels = {
  regexToggle: {
    info: 'Use regular expression search',
    error: 'Invalid regular expression provided'
  }
};
export class QueryForm extends React.PureComponent {
  constructor(props) {
    super(props);
    _defineProperty(this, "inputSearchRef", /*#__PURE__*/React.createRef());
    _defineProperty(this, "handleSubmit", evt => {
      evt.preventDefault();
    });
    _defineProperty(this, "handleButtonGroupClick", isAsc => {
      this.props.onFormValuesChange({
        isAscendingQueryComparatorOrder: isAsc
      });
    });
    _defineProperty(this, "handleSelectComparatorChange", option => {
      if (typeof option?.value === 'string') {
        this.props.onFormValuesChange({
          queryComparator: option.value
        });
      }
    });
    _defineProperty(this, "handleSelectFilterChange", option => {
      if (typeof option?.value === 'string') {
        this.props.onFormValuesChange({
          queryFilter: option.value
        });
      }
    });
    _defineProperty(this, "handleRegexSearchClick", () => {
      this.props.onFormValuesChange({
        isRegexSearch: !this.props.values.isRegexSearch
      });
    });
    _defineProperty(this, "restoreCaretPosition", (start, end) => {
      window.requestAnimationFrame(() => {
        if (this.inputSearchRef.current) {
          this.inputSearchRef.current.selectionStart = start;
          this.inputSearchRef.current.selectionEnd = end;
        }
      });
    });
    _defineProperty(this, "invalidateSearchValueFromProps", debounce(() => {
      this.props.onFormValuesChange({
        searchValue: this.state.searchValue
      });
    }, 150));
    _defineProperty(this, "handleSearchChange", evt => {
      const searchValue = evt.target.value.trim();
      this.setState({
        searchValue
      });
      this.invalidateSearchValueFromProps();
    });
    _defineProperty(this, "handleClearSearchClick", evt => {
      evt.preventDefault();
      if (this.state.searchValue) {
        this.setState({
          searchValue: ''
        });
        this.invalidateSearchValueFromProps();
      }
    });
    this.state = {
      searchValue: props.values.searchValue
    };
  }
  render() {
    const {
      searchQueryRegex,
      values: {
        isAscendingQueryComparatorOrder: isAsc,
        queryComparator,
        searchValue,
        queryFilter,
        isRegexSearch
      }
    } = this.props;
    const isRegexInvalid = isRegexSearch && searchValue.length > 0 && searchQueryRegex == null;
    const regexToggleType = isRegexInvalid ? 'error' : 'info';
    const regexToggleLabel = labels.regexToggle[regexToggleType];
    return /*#__PURE__*/React.createElement(StyleUtilsContext.Consumer, null, _ref => {
      let {
        styling,
        base16Theme
      } = _ref;
      return /*#__PURE__*/React.createElement("form", _extends({
        id: "rtk-query-monitor-query-selection-form",
        action: "#",
        onSubmit: this.handleSubmit
      }, styling('queryForm')), /*#__PURE__*/React.createElement("div", styling('queryListHeader'), /*#__PURE__*/React.createElement("label", _extends({
        htmlFor: searchId
      }, styling('srOnly')), "filter query"), /*#__PURE__*/React.createElement("div", styling('querySearch'), /*#__PURE__*/React.createElement("input", {
        ref: this.inputSearchRef,
        type: "search",
        value: this.state.searchValue,
        onChange: this.handleSearchChange,
        placeholder: searchPlaceholder
      }), /*#__PURE__*/React.createElement("button", _extends({
        type: "reset",
        "aria-label": "clear search",
        "data-invisible": +(this.state.searchValue.length === 0) || undefined,
        onClick: this.handleClearSearchClick
      }, styling('closeButton'))), /*#__PURE__*/React.createElement("button", _extends({
        type: "button",
        "aria-label": regexToggleLabel,
        title: regexToggleLabel,
        "data-type": regexToggleType,
        "aria-pressed": isRegexSearch,
        onClick: this.handleRegexSearchClick
      }, styling('toggleButton')), /*#__PURE__*/React.createElement(RegexIcon, null))), /*#__PURE__*/React.createElement("label", _extends({
        htmlFor: selectId
      }, styling('srOnly')), "filter by"), /*#__PURE__*/React.createElement(Select, {
        id: filterSelectId,
        isSearchable: false,
        options: filterQueryOptions,
        theme: base16Theme,
        value: filterQueryOptions.find(opt => opt?.value === queryFilter),
        onChange: this.handleSelectFilterChange
      })), /*#__PURE__*/React.createElement("div", styling('sortBySection'), /*#__PURE__*/React.createElement("label", {
        htmlFor: selectId
      }, "Sort by"), /*#__PURE__*/React.createElement(Select, {
        id: selectId,
        isSearchable: false,
        theme: base16Theme,
        value: sortQueryOptions.find(opt => opt?.value === queryComparator),
        options: sortQueryOptions,
        onChange: this.handleSelectComparatorChange
      }), /*#__PURE__*/React.createElement(SortOrderButton, {
        id: 'rtk-query-sort-order-button',
        isAsc: isAsc,
        onChange: this.handleButtonGroupClick
      })));
    });
  }
}